@@ -16,16 +16,15 @@
 //
 //
 
-#ifndef GRPC_CORE_LIB_SURFACE_EVENT_STRING_H
-#define GRPC_CORE_LIB_SURFACE_EVENT_STRING_H
-
-#include <grpc/support/port_platform.h>
+#ifndef GRPC_SRC_CORE_LIB_SURFACE_EVENT_STRING_H
+#define GRPC_SRC_CORE_LIB_SURFACE_EVENT_STRING_H
 
 #include <string>
 
 #include <grpc/grpc.h>
+#include <grpc/support/port_platform.h>
 
 // Returns a string describing an event. Must be later freed with gpr_free()
 std::string grpc_event_string(grpc_event* ev);
 
-#endif  // GRPC_CORE_LIB_SURFACE_EVENT_STRING_H
+#endif  // GRPC_SRC_CORE_LIB_SURFACE_EVENT_STRING_H
