@@ -19,16 +19,15 @@
 #ifndef GRPC_SRC_CORE_LIB_SURFACE_VALIDATE_METADATA_H
 #define GRPC_SRC_CORE_LIB_SURFACE_VALIDATE_METADATA_H
 
-#include <grpc/support/port_platform.h>
-
 #include <stdint.h>
 
 #include <cstring>
 
+#include "absl/log/check.h"
 #include "absl/strings/string_view.h"
 
 #include <grpc/slice.h>
-#include <grpc/support/log.h>
+#include <grpc/support/port_platform.h>
 
 #include "src/core/lib/iomgr/error.h"
 
@@ -59,7 +58,7 @@ inline int grpc_key_is_binary_header(const uint8_t* buf, size_t length) {
   return 0 == memcmp(buf + length - 4, "-bin", 4);
 }
 inline int grpc_is_refcounted_slice_binary_header(const grpc_slice& slice) {
-  GPR_DEBUG_ASSERT(slice.refcount != nullptr);
+  DCHECK_NE(slice.refcount, nullptr);
   return grpc_key_is_binary_header(slice.data.refcounted.bytes,
                                    slice.data.refcounted.length);
 }
