@@ -12,8 +12,6 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#include <grpc/support/port_platform.h>
-
 #include "src/core/lib/transport/promise_endpoint.h"
 
 #include <atomic>
@@ -21,13 +19,14 @@
 #include <memory>
 #include <utility>
 
+#include "absl/log/check.h"
 #include "absl/status/status.h"
 #include "absl/types/optional.h"
 
 #include <grpc/event_engine/event_engine.h>
 #include <grpc/event_engine/slice_buffer.h>
 #include <grpc/slice_buffer.h>
-#include <grpc/support/log.h>
+#include <grpc/support/port_platform.h>
 
 #include "src/core/lib/gprpp/sync.h"
 #include "src/core/lib/slice/slice_buffer.h"
@@ -39,7 +38,7 @@ PromiseEndpoint::PromiseEndpoint(
         endpoint,
     SliceBuffer already_received)
     : endpoint_(std::move(endpoint)) {
-  GPR_ASSERT(endpoint_ != nullptr);
+  CHECK_NE(endpoint_, nullptr);
   read_state_->endpoint = endpoint_;
   // TODO(ladynana): Replace this with `SliceBufferCast<>` when it is
   // available.
@@ -58,50 +57,53 @@ PromiseEndpoint::GetLocalAddress() const {
 }
 
 void PromiseEndpoint::ReadState::Complete(absl::Status status,
-                                          size_t num_bytes_requested) {
-  if (!status.ok()) {
-    // Invalidates all previous reads.
-    pending_buffer.Clear();
-    buffer.Clear();
+                                          const size_t num_bytes_requested) {
+  while (true) {
+    if (!status.ok()) {
+      // Invalidates all previous reads.
+      pending_buffer.Clear();
+      buffer.Clear();
+      result = status;
+      auto w = std::move(waker);
+      complete.store(true, std::memory_order_release);
+      w.Wakeup();
+      return;
+    }
+    // Appends `pending_buffer` to `buffer`.
+    pending_buffer.MoveFirstNBytesIntoSliceBuffer(pending_buffer.Length(),
+                                                  buffer);
+    DCHECK(pending_buffer.Count() == 0u);
+    if (buffer.Length() < num_bytes_requested) {
+      // A further read is needed.
+      // Set read args with number of bytes needed as hint.
+      grpc_event_engine::experimental::EventEngine::Endpoint::ReadArgs
+          read_args = {
+              static_cast<int64_t>(num_bytes_requested - buffer.Length())};
+      // If `Read()` returns true immediately, the callback will not be
+      // called. We still need to call our callback to pick up the result and
+      // maybe do further reads.
+      auto ep = endpoint.lock();
+      if (ep == nullptr) {
+        status = absl::UnavailableError("Endpoint closed during read.");
+        continue;
+      }
+      if (ep->Read(
+              [self = Ref(), num_bytes_requested](absl::Status status) {
+                ApplicationCallbackExecCtx callback_exec_ctx;
+                ExecCtx exec_ctx;
+                self->Complete(std::move(status), num_bytes_requested);
+              },
+              &pending_buffer, &read_args)) {
+        continue;
+      }
+      return;
+    }
     result = status;
     auto w = std::move(waker);
     complete.store(true, std::memory_order_release);
     w.Wakeup();
     return;
   }
-  // Appends `pending_buffer` to `buffer`.
-  pending_buffer.MoveFirstNBytesIntoSliceBuffer(pending_buffer.Length(),
-                                                buffer);
-  GPR_DEBUG_ASSERT(pending_buffer.Count() == 0u);
-  if (buffer.Length() < num_bytes_requested) {
-    // A further read is needed.
-    // Set read args with number of bytes needed as hint.
-    grpc_event_engine::experimental::EventEngine::Endpoint::ReadArgs read_args =
-        {static_cast<int64_t>(num_bytes_requested - buffer.Length())};
-    // If `Read()` returns true immediately, the callback will not be
-    // called. We still need to call our callback to pick up the result and
-    // maybe do further reads.
-    auto ep = endpoint.lock();
-    if (ep == nullptr) {
-      Complete(absl::UnavailableError("Endpoint closed during read."),
-               num_bytes_requested);
-      return;
-    }
-    if (ep->Read(
-            [self = Ref(), num_bytes_requested](absl::Status status) {
-              ApplicationCallbackExecCtx callback_exec_ctx;
-              ExecCtx exec_ctx;
-              self->Complete(std::move(status), num_bytes_requested);
-            },
-            &pending_buffer, &read_args)) {
-      Complete(std::move(status), num_bytes_requested);
-    }
-    return;
-  }
-  result = status;
-  auto w = std::move(waker);
-  complete.store(true, std::memory_order_release);
-  w.Wakeup();
 }
 
 }  // namespace grpc_core
